@@ -106,7 +106,7 @@ extern "C" {
 #  define magick_unreferenced(x)  /* nothing */
 #endif
 
-#if !defined(__clang__) && (((__GNUC__) > 4) || ((__GNUC__ == 4) && (__GNUC_MINOR__ >= 3)))
+#if !defined(__clang__) && (defined(__GNUC__) && (__GNUC__) > 4)
 #  define magick_alloc_size(x)  __attribute__((__alloc_size__(x)))
 #  define magick_alloc_sizes(x,y)  __attribute__((__alloc_size__(x,y)))
 #  define magick_fallthrough  __attribute__((fallthrough))
@@ -116,7 +116,7 @@ extern "C" {
 #  define magick_fallthrough  /* nothing */
 #endif
 
-#if defined(__clang__) || (((__GNUC__) > 4) || ((__GNUC__ == 4) && (__GNUC_MINOR__ >= 3)))
+#if defined(__clang__) || (defined(__GNUC__) && (__GNUC__) > 4)
 #  define magick_cold_spot  __attribute__((__cold__))
 #  define magick_hot_spot  __attribute__((__hot__))
 #else
